.. sphinxcontrib-wiki documentation wiki

====
Wiki
====

.. wikipage:: intro
  :title: Introduction

.. wikipage:: faq
   :title: Potentially Asked Questions

.. wikipage:: todo
  :title: To Do List
